GlobalPropsModified class

Constructors

GlobalPropsModified()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

parseDataType(String input) → ParsedData?
parseMultiDataType(String input) → List<ParsedData?>
updatePropsByState(Map<String, dynamic> json, String stateVariable) → Map<String, dynamic>